@@ -189,6 +189,7 @@ cspi_init_role_table (AccessibleRole *role_table)
   role_table [Accessibility_ROLE_RULER] = SPI_ROLE_RULER;
   role_table [Accessibility_ROLE_APPLICATION] = SPI_ROLE_APPLICATION;
   role_table [Accessibility_ROLE_AUTOCOMPLETE] = SPI_ROLE_AUTOCOMPLETE;
+  role_table [Accessibility_ROLE_EDITBAR] = SPI_ROLE_EDITBAR;
 
   return TRUE;
 }
@@ -498,6 +499,32 @@ Accessible_getRoleName (Accessible *obj)
   return retval;
 }
 
+/**
+ * Accessible_getLocalizedRoleName:
+ * @obj: a pointer to the #Accessible object on which to operate.
+ *
+ * Get a UTF-8 string describing the (localized) role this object plays in the UI.
+ * This method will return useful values for roles that fall outside the
+ * enumeration used in Accessible_getRole ().
+ *
+ * Returns: a UTF-8 string specifying the role of this #Accessible object.
+ *
+ **/
+char *
+Accessible_getLocalizedRoleName (Accessible *obj)
+{
+  char *retval;
+
+  cspi_return_val_if_fail (obj != NULL, CORBA_string_dup ("invalid"));
+
+  retval = 
+    Accessibility_Accessible_getLocalizedRoleName (CSPI_OBJREF (obj), cspi_ev ());
+
+  cspi_return_val_if_ev ("getLocalizedRoleName", CORBA_string_dup ("invalid")); 
+
+  return retval;
+}
+
 /**
  * Accessible_getStateSet:
  * @obj: a pointer to the #Accessible object on which to operate.
@@ -988,7 +1015,6 @@ cspi_init_relation_type_table (AccessibleRelationType *relation_type_table)
   relation_type_table [Accessibility_RELATION_EMBEDS] = SPI_RELATION_EMBEDS;
   relation_type_table [Accessibility_RELATION_EMBEDDED_BY] = SPI_RELATION_EMBEDDED_BY;
   relation_type_table [Accessibility_RELATION_POPUP_FOR] = SPI_RELATION_POPUP_FOR;
-  relation_type_table [Accessibility_RELATION_LAST_DEFINED] = SPI_RELATION_LAST_DEFINED;
   return TRUE;
 }
 
